clearvars;

Bo_B1_vD_FLAG = 3; % 1 - Bo modulation; 2 - B1 modulation; 3 - dipolar coupling
MAS = [10;20;30;40];  % MAS values
Amp_max_B0 = 200; % the max. B_0 amplitude modulation in Hz
Amp_max_B1 = 1;  % the max. B_1 amplitude modulation in % with respect to splin-lock strength
v_D = 200;  % dipolar coupling value in Hz


if Bo_B1_vD_FLAG == 1
    a12_ratio(1:2,1) = [1;0.5];
    Siz = 1;
    Norm_A = 1;    
    name_mod = "B_0 modulation";
    a_x = Amp_max_B0/1000;
elseif Bo_B1_vD_FLAG == 2
    a12_ratio(1:2,1) = [1;0.25];
    Siz = 1;
    Norm_A = 1;
    name_mod = "B_1 modulation";
    a_x = Amp_max_B1/100;
elseif Bo_B1_vD_FLAG == 3    
    A=dlmread('100.dat');
    Siz=length(A);
    Norm_A = A(1,4);
    name_mod = "dipolar interaction";
    a_x = v_D/1000;
else
    error("Bo_B1_vD_FLAG should be 1, 2 or 3");
    
end
Teff = 200000;     % T2 relaxation in ms

dt = 0.01;
t_R = (0:dt:1)';
I=[1,0;0,1];
I_z=0.5*[1,0;0,-1];
I_x=0.5*[0,1;1,0];
I_y=0.5*[0,-1i;1i,0];
if Bo_B1_vD_FLAG < 3
    Ix = I_x;
    Iy = I_y;
    Iz = I_z;
    dim = 2;
elseif Bo_B1_vD_FLAG == 3   
    Ix = kron(I_x,I);
    Iy = kron(I_y,I);
    Iz = kron(I_z,I);                    
    H_D = 2*kron(I_z,I_z); 
    dim = 4;
end
    
Norm = trace(Ix*Ix);
a=[0;1;0;0;0;0;0.5;1;1;0.5;0.6;1;0.5;0.6;0.6;0.3;0.6;0;0;0.2];
b=[0;0;0;1;1;1;0.5;1;0.5;0;0.2;0.6;0.5;0;0.3;0;0;0.5;0.6;0.2];
c=[0;0;1;1;0;1;0.5;0;0;1;1;0.2;0.5;0;0;0.6;0.3;1;0.3;0.2];

a_k=[1; 0.5; 1; 1.37;]/100;
SP_L = {};
for aa=1:2
    figure(aa);
    clf;
    subplot(1,1,1, 'Position',[0.14 0.13 0.855 0.865])
    for aaa=1:length(MAS)
        v_R = MAS(aaa,1);
        V_RF_T = aa*v_R;     
        v_rf = V_RF_T/v_R; 
        MAS_Factor = v_R/10;
        N_time =300*MAS_Factor;
        N_mix = (0:4:N_time);        
        if Bo_B1_vD_FLAG == 2
            ax = a_x*v_rf;
        else
            ax = a_x/v_R;
        end
        Signal_Numerical=0;
        Signal_FOH = 0;
        Ak = 0;
        t = 0; 
        for ab=1:Siz             
            off = 0/v_R;
            Tot_S = 0;
                            
            V=eye([dim dim]); 
            for ac=1:(length(t_R)-1)          
                if Bo_B1_vD_FLAG == 3 
                    ti=t_R(ac);
                    tf=t_R(ac+1);                 
                    VD=0.5*ID(A(ab,1),A(ab,2),A(ab,3),0,0,ti,tf);                
                    H = 2*pi*v_rf*dt*Ix + 2*pi*off*dt*Iz+2*pi*ax*VD*H_D; 
                    a12_ratio = [sqrt(0.5)*sin(2*A(ab,2));-0.5*(sin(A(ab,2)))^2];
                else
                    H = 2*pi*v_rf*dt*Ix + 2*pi*off*dt*Iz+...
                        (a12_ratio(1,1)*ax*(sin(2*pi*t_R(ac+1)) - sin(2*pi*t_R(ac)))+0.5*ax*a12_ratio(2,1)*(sin(4*pi*t_R(ac+1)) - sin(4*pi*t_R(ac))))*(Iz);
                end
                [V1,E]=eig(H);
                Eh=eye([dim dim]);
                for ss=1:dim
                    Eh(ss,ss)=exp(-1i*E(ss,ss));
                end
                H1=V1*Eh/V1;   
                V=H1*V;     
            end
            W = eye([dim dim]);
            for ac=1:N_time               
                pho = W*Ix/W; 
                t(ac,1) = (ac-1)/v_R;
                Ak(ac,1) = (real(trace(pho*Ix))/(Norm));
                W = W*V;
            end
            Signal_Numerical = Signal_Numerical+Ak*Norm_A;
            Signal_FOH = Signal_FOH + cos(pi*N_mix*a12_ratio(aa,1)*ax)*Norm_A;
        end
   
        Signal_Numerical = Signal_Numerical/Signal_Numerical(1,1);
        hPlot=plot(t,Signal_Numerical,'Color',[a(aaa,1),b(aaa,1),c(aaa,1)]);  
        set(hPlot,'Marker','none','MarkerSize',10,'LineStyle','-');
        hold on         
        t_mix = N_mix/v_R;
        hPlot=plot(t_mix,Signal_FOH,'Color',[a(aaa,1),b(aaa,1),c(aaa,1)]);  
        set(hPlot,'Marker','*','MarkerSize',10,'LineStyle','none');
        hold on 
        SP_L= [SP_L, MAS(aa,1),"FOH"];
    end


    name_X = name_mod + ': {\nu}_{SL}=' + aa + '{\nu}_R'; 
    text(0.1*max(t_mix),1.08,name_X,'Fontsize',24,'Color',[0.5 0.5 0.5]);

    leg = legend(SP_L,'Fontsize',18,'EdgeColor','None');
    
    title(leg, 'MAS (in kHz)');
    xlabel('t_{SL} (ms)','LineWidth',22);
    ylabel('S_{SL} (t_{SL})','LineWidth',22);
    axis([0,1.3*max(t),-1.15,1.15]);
    hAxes = gca;
    set(hAxes,'xtick', [5 10 15 20 25 30]);
    set(hAxes,'ytick', [-1 -0.8 -0.6 -0.4 -0.2 0 0.2 0.4 0.6 0.8 1])
    set(gca,'FontSize',24)
    set(findall(gcf,'-property','FontWeight'),'FontWeight','bold')
    set(findall(gcf,'-property','LineWidth'),'LineWidth',2) 
end

